package AbsenceTypes;

use FileHandle;

use AbsenceConfig;

BEGIN {
	$TYPE_FILE = AbsenceConfig::fetch('type_file');
	%DB = ();

	$INIT_RUN	= 0;
	$DEFAULT	= '';
	$VERSION 	= '1.0';
}

sub readFile
{
	my $fh = FileHandle->new($TYPE_FILE);
	defined($fh) || die "open $TYPE_FILE for reading";
	my ($type, $color);
	while(<$fh>) {
		if (/^\s*#/) { next; }
		if (/^\s*$/) { next; }
		if (/^Type:\s+(\S+)\s+(\S+)\s+(\S+)\s+(\S+)\s*(#.*)?$/) {
			$type = $1;
			$color = [$2, $3, $4];	# rgb
			$DB{$type} = $color;
		} elsif (/^\s*Default: (\S+)\s*$/) {
			$DEFAULT = $1;
		}
	}
	$fh->close;

	if ($DEFAULT && !exists($DB{$DEFAULT})) {
		$DEFAULT = '';
	}

	$INIT_RUN = 1;
}

sub getTypes
{
	if (!$INIT_RUN) { readFile(); }
	return keys(%DB);
}

sub getColor
{
	my $type = shift;

	if (!$INIT_RUN) { readFile(); }

	if (!exists($DB{$type})) {
		return undef;
	}

	return $DB{$type};
}

sub getHash
{
	if (!$INIT_RUN) { readFile(); }
	return \%DB;
}

sub getDefault
{
	if ($DEFAULT) {
		return $DEFAULT;
	}

	return undef;
}

sub modTime
{
	return (stat($TYPE_FILE))[9];
}

1;
